# Orange3 Educational Add-on

Widgets in Educational Add-on demonstrate several key data mining and machine learning procedures. The widgets are useful for beginners to understand the inner working of key algorithms in the data mining and for teachers to be able to visually explain various methods in a classroom.

## Widgets

- Google Sheets
- EnKlik Anketa
- Interactive k-means
- Gradient Descent
- Polynomial Regression
- Polynomial Classification
- Pie Chart
- Random Data

# Indices and tables

- Index

- Module Index

- Search Page